pub trait TransformConfig: Send + Sync {
// Required method
fn build(&self, cx: TransformContext) -> Result<JoinHandle<()>>;
}Expand description
Trait for component configurations that can build a transform task.
pub trait TransformConfig: Send + Sync {
// Required method
fn build(&self, cx: TransformContext) -> Result<JoinHandle<()>>;
}Trait for component configurations that can build a transform task.