TlsConfig

Struct TlsConfig 

pub struct TlsConfig {
    pub enabled: bool,
    pub ca_file: Option<PathBuf>,
    pub crt_file: Option<PathBuf>,
    pub key_file: Option<PathBuf>,
    pub insecure_skip_verify: bool,
}
Standard TLS configuration options available to any component that opens network connections or binds to a port.

Fields

enabled: bool

Whether TLS is enabled.

ca_file: Option<PathBuf>

Path to a PEM-encoded CA certificate file to use for verifying peers.

crt_file: Option<PathBuf>

Path to a PEM-encoded certificate file for mutual TLS.

key_file: Option<PathBuf>

Path to a PEM-encoded private key file for mutual TLS.

insecure_skip_verify: bool

Whether to skip certificate verification. Insecure — use only for testing.

Implementations

Source

impl TlsConfig

pub fn build(&self) -> Result<(), Error>

Loads the actual certificate data from disk if TLS is enabled.

Returns

Currently returns Ok(()). In the future, this will build a rustls::ClientConfig or rustls::ServerConfig.